@@ -1091,6 +1091,14 @@ def get_files(search_path=False, **kwargs):
 
             [`ftp`=None] {obj}
                 A reference to the ftputil object.
+                
+            [`include_meta_data`=False] {bool}
+                If True any images that are found will have their meta_data added to the file object.
+                
+                Bare in mind that not all images support keywords etc. Currently, only jpg and tiff allow it.
+                
+                
+                This will slow things down a bit.
 
         return
         ----------
@@ -1106,11 +1114,17 @@ def get_files(search_path=False, **kwargs):
 
     threaded = obj.get_kwarg(['threaded', 'thread'], True, bool, **kwargs)
     recursive = obj.get_kwarg(['recursive', 'recurse'], True, bool, **kwargs)
-    include_meta_data = obj.get_kwarg(['image meta data', 'meta data'], False, bool, **kwargs)
+    include_meta_data = obj.get_kwarg(['image meta data', 'meta data','include meta data'], False, bool, **kwargs)
 
     data_include = obj.get_kwarg(['data include'], [], (list, str), **kwargs)
     if isinstance(data_include, (str)):
         data_include = [data_include]
+        # if data_include is provided and include_meta_data is True
+        if include_meta_data is True and len(data_include) > 0:
+            # Confirm that extension is in data_include, if not, add it.
+            # The extension is required to gather the data.
+            if "extension" not in data_include:
+                data_include.append("extension")
 
     # ignore_array = obj.get_kwarg(['ignore', 'ignore_array', 'exclude'], [], (str, list), **kwargs)
     exclude = obj.get_kwarg(['exclude', 'ignore', 'ignore array'], [], (list, str), **kwargs)
@@ -1131,7 +1145,7 @@ def get_files(search_path=False, **kwargs):
 
     if threaded is True:
         for path in search_path:
-            gft = GetFilesThreaded(path, recursive=recursive, data_include=data_include, exclude=exclude, include=include, extensions=extension_array)
+            gft = GetFilesThreaded(path, recursive=recursive, data_include=data_include, exclude=exclude, include=include, extensions=extension_array,include_meta_data=include_meta_data)
             return gft.master()
     # print(json.dumps(extension_array, indent=4))
     for path in search_path:
@@ -1378,6 +1392,9 @@ class GetFilesThreaded:
         if isinstance(self.extension_array, (str)):
             self.extension_array = [self.extension_array]
 
+        self.include_meta_data = obj.get_kwarg(['image meta data', 'meta data','include meta data'], False, bool, **kwargs)
+
+
     def remove_thread_by_id(self, thread_id):
         '''
             Removes an active thread from self.threads
@@ -1493,7 +1510,8 @@ class GetFilesThreaded:
         # print(f"                                                                                                                      ", end="\r", flush=True)
         for thread in self.thread_array:
             thread.join()
-        self.file_array = _add_jpg_meta_data(self.file_array)
+        if self.include_meta_data is True:
+            self.file_array = _add_jpg_meta_data(self.file_array)
         return self.file_array
 
         # def _get_files_single_thread(search_path=False, recursive=False, exclude=None, include=None, extensions=None, data_include=None):
